@@ -6,7 +6,7 @@ from notetool.log import logger
 from tqdm import tqdm
 
 
-def load_source(urls=None, cate1='1', book: BookSource = None):
+def load_from_url(urls=None, cate1='1', book: BookSource = None):
     book = book or BookSource(lanzou_fid=4147049)
     for url in tqdm(urls):
         try:
